@@ -58,7 +58,7 @@ impl NewArgs {
 
         let title = self.title.as_deref();
 
-        let mut file = env::current_dir().expect("How does this fail?");
+        let mut file = env::current_dir().unwrap_or_default();
         if let Some(rel_file) = self.file.as_deref() {
             file.push(rel_file)
         }
@@ -100,7 +100,7 @@ impl RenameArgs {
 
         let title = self.title.as_ref();
 
-        let mut file = env::current_dir().expect("How does this fail?");
+        let mut file = env::current_dir().unwrap_or_default();
         if let Some(rel_file) = self.file.as_deref() {
             file.push(rel_file)
         }
@@ -130,7 +130,7 @@ impl PublishArgs {
         let config = cobalt::cobalt_model::Config::from_config(config)?;
 
         let filename = self.filename.as_path();
-        let mut file = env::current_dir().expect("How does this fail?");
+        let mut file = env::current_dir().unwrap_or_default();
         file.push(path::Path::new(filename));
 
         publish_document(&config, &file)
